/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();
};

MainWindow::MainWindow()
{
   setMinimumSize(600, 400);

   //
   QLabel *label_1 = new QLabel("Line Edit:");

   QLineEdit *text_1 = new QLineEdit();
   text_1->setText("Single line of text");

   //
   QLabel *label_2 = new QLabel("Text Edit:");

   QTextEdit *text_2 = new QTextEdit();
   text_2->setText("Multiple lines using html text formatting."
        "<br>"
        "<span style=\"color:#aa00ff;\">Show text in magenta</span>"
        "<br>"
        "<span style=\"font-size:10pt;\">Set 10 pt font</span>");
   text_2->setMaximumHeight(100);

   //
   QLabel *label_3 = new QLabel("Plain Text:");

   QPlainTextEdit *text_3 = new QPlainTextEdit();
   text_3->setPlainText("Multiple lines, no formatting");
   text_3->setMaximumHeight(100);

   QPushButton *pb_1 = new QPushButton();
   pb_1->setText("Close");

   QGridLayout *layout1 = new QGridLayout();
   layout1->setVerticalSpacing(20);

   layout1->addWidget(label_1, 0, 1);
   layout1->addWidget(text_1, 0, 2);
   layout1->addWidget(label_2, 1, 1, Qt::AlignTop);
   layout1->addWidget(text_2, 1, 2);
   layout1->addWidget(label_3, 2, 1, Qt::AlignTop);
   layout1->addWidget(text_3, 2, 2);

   QHBoxLayout *layout2 = new QHBoxLayout();
   layout2->addStretch();
   layout2->addWidget(pb_1);
   layout2->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->setContentsMargins(45, 35, 45, 15);

   layoutMain->addLayout(layout1);
   layoutMain->addSpacing(20);
   layoutMain->addLayout(layout2);

   connect(pb_1, &QPushButton::clicked, this, &QWidget::close);
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}